// SPDX-FileCopyrightText: 2024 Yury Gubich <blue@macaw.me>
// SPDX-License-Identifier: GPL-3.0-or-later

#include "jay.h"
#include "logger.h"

#include <string>
#include <sstream>
#include <iostream>

std::string readEnv(const std::string& key, const std::string& defaultValue = "") {
    const char* val = std::getenv(key.data());
    if (val)
        return std::string(val);

    return defaultValue;
}

int main(int argc, char** argv) {
    std::string jid = readEnv("JID");
    std::string password = readEnv("PASSWORD");

    if (jid.empty() || password.empty()) {
        std::cout << "You need to provide JID and PASSWORD environment variables" << std::endl;
        return - 1;
    }

    Jay bot(jid, password);
    bot.addLogger(gloox::LogLevelDebug);

    std::string owners = readEnv("OWNERS");
    std::stringstream ss(owners);
    std::string owner;
    while (std::getline(ss, owner, ','))
        bot.addOwner(owner);

    bot.run();

    return 0;
}
